The API wrapper functions in this package rely on basic authentication via username
and password residing in the environment variables RAVELRY_USERNAME and
RAVELRY_PASSWORD. The easiest way to accomplish this is to set it in
the `.Renviron` file in your home directory. If you do not have these
credentials, you can create them at https://www.ravelry.com/pro/developer.
ravelry_auth(key = "username", overwrite = FALSE)the variable to set - either username or password
overwrite the existing variable in the current environment?
atomic character vector containing the username or password credential